# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKOptimizersv4Python



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkRegularStepGradientDescentOptimizerv4Python
else:
    import _itkRegularStepGradientDescentOptimizerv4Python

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkGradientDescentOptimizerv4Python
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkGradientDescentOptimizerBasev4Python
import itk.itkObjectToObjectOptimizerBasePython
import itk.itkOptimizerParametersPython
import itk.itkArrayPython
import itk.itkOptimizerParameterScalesEstimatorPython
import itk.itkObjectToObjectMetricBasePython
import itk.itkSingleValuedCostFunctionv4Python
import itk.itkCostFunctionPython

def itkRegularStepGradientDescentOptimizerv4D_New():
    return itkRegularStepGradientDescentOptimizerv4D.New()

class itkRegularStepGradientDescentOptimizerv4D(itk.itkGradientDescentOptimizerv4Python.itkGradientDescentOptimizerv4TemplateD):
    r"""Proxy of C++ itkRegularStepGradientDescentOptimizerv4D class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRegularStepGradientDescentOptimizerv4D_Pointer"""
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4D___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRegularStepGradientDescentOptimizerv4D_Pointer"""
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4D_Clone(self)

    def SetMinimumStepLength(self, _arg):
        r"""
        SetMinimumStepLength(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4D_SetMinimumStepLength(self, _arg)

    def GetMinimumStepLength(self):
        r"""GetMinimumStepLength(self) -> double const &"""
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4D_GetMinimumStepLength(self)

    def SetRelaxationFactor(self, _arg):
        r"""
        SetRelaxationFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4D_SetRelaxationFactor(self, _arg)

    def GetRelaxationFactor(self):
        r"""GetRelaxationFactor(self) -> double const &"""
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4D_GetRelaxationFactor(self)

    def SetGradientMagnitudeTolerance(self, _arg):
        r"""
        SetGradientMagnitudeTolerance(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4D_SetGradientMagnitudeTolerance(self, _arg)

    def GetGradientMagnitudeTolerance(self):
        r"""GetGradientMagnitudeTolerance(self) -> double const &"""
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4D_GetGradientMagnitudeTolerance(self)

    def SetCurrentLearningRateRelaxation(self, _arg):
        r"""
        SetCurrentLearningRateRelaxation(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4D_SetCurrentLearningRateRelaxation(self, _arg)

    def GetCurrentLearningRateRelaxation(self):
        r"""GetCurrentLearningRateRelaxation(self) -> double const &"""
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4D_GetCurrentLearningRateRelaxation(self)

    def StartOptimization(self, doOnlyInitialization=False):
        r"""
        StartOptimization(self, doOnlyInitialization=False)

        Parameters
        ----------
        doOnlyInitialization: bool

        """
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4D_StartOptimization(self, doOnlyInitialization)

    def GetCurrentStepLength(self):
        r"""GetCurrentStepLength(self) -> double"""
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4D_GetCurrentStepLength(self)
    __swig_destroy__ = _itkRegularStepGradientDescentOptimizerv4Python.delete_itkRegularStepGradientDescentOptimizerv4D

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRegularStepGradientDescentOptimizerv4D

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4D_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRegularStepGradientDescentOptimizerv4D

        Create a new object of the class itkRegularStepGradientDescentOptimizerv4D and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRegularStepGradientDescentOptimizerv4D.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRegularStepGradientDescentOptimizerv4D.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRegularStepGradientDescentOptimizerv4D.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRegularStepGradientDescentOptimizerv4D in _itkRegularStepGradientDescentOptimizerv4Python:
_itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4D_swigregister(itkRegularStepGradientDescentOptimizerv4D)

def itkRegularStepGradientDescentOptimizerv4F_New():
    return itkRegularStepGradientDescentOptimizerv4F.New()

class itkRegularStepGradientDescentOptimizerv4F(itk.itkGradientDescentOptimizerv4Python.itkGradientDescentOptimizerv4TemplateF):
    r"""Proxy of C++ itkRegularStepGradientDescentOptimizerv4F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRegularStepGradientDescentOptimizerv4F_Pointer"""
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4F___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRegularStepGradientDescentOptimizerv4F_Pointer"""
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4F_Clone(self)

    def SetMinimumStepLength(self, _arg):
        r"""
        SetMinimumStepLength(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4F_SetMinimumStepLength(self, _arg)

    def GetMinimumStepLength(self):
        r"""GetMinimumStepLength(self) -> float const &"""
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4F_GetMinimumStepLength(self)

    def SetRelaxationFactor(self, _arg):
        r"""
        SetRelaxationFactor(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4F_SetRelaxationFactor(self, _arg)

    def GetRelaxationFactor(self):
        r"""GetRelaxationFactor(self) -> float const &"""
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4F_GetRelaxationFactor(self)

    def SetGradientMagnitudeTolerance(self, _arg):
        r"""
        SetGradientMagnitudeTolerance(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4F_SetGradientMagnitudeTolerance(self, _arg)

    def GetGradientMagnitudeTolerance(self):
        r"""GetGradientMagnitudeTolerance(self) -> float const &"""
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4F_GetGradientMagnitudeTolerance(self)

    def SetCurrentLearningRateRelaxation(self, _arg):
        r"""
        SetCurrentLearningRateRelaxation(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4F_SetCurrentLearningRateRelaxation(self, _arg)

    def GetCurrentLearningRateRelaxation(self):
        r"""GetCurrentLearningRateRelaxation(self) -> float const &"""
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4F_GetCurrentLearningRateRelaxation(self)

    def StartOptimization(self, doOnlyInitialization=False):
        r"""
        StartOptimization(self, doOnlyInitialization=False)

        Parameters
        ----------
        doOnlyInitialization: bool

        """
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4F_StartOptimization(self, doOnlyInitialization)

    def GetCurrentStepLength(self):
        r"""GetCurrentStepLength(self) -> double"""
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4F_GetCurrentStepLength(self)
    __swig_destroy__ = _itkRegularStepGradientDescentOptimizerv4Python.delete_itkRegularStepGradientDescentOptimizerv4F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRegularStepGradientDescentOptimizerv4F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4F_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRegularStepGradientDescentOptimizerv4F

        Create a new object of the class itkRegularStepGradientDescentOptimizerv4F and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRegularStepGradientDescentOptimizerv4F.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRegularStepGradientDescentOptimizerv4F.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRegularStepGradientDescentOptimizerv4F.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRegularStepGradientDescentOptimizerv4F in _itkRegularStepGradientDescentOptimizerv4Python:
_itkRegularStepGradientDescentOptimizerv4Python.itkRegularStepGradientDescentOptimizerv4F_swigregister(itkRegularStepGradientDescentOptimizerv4F)

